@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2023, Intel Corporation
+* Copyright (c) 2020-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -552,16 +552,6 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpPipeModeSelectCmd(
     cmd.DW3.PicStatusErrorReportId                      = false;
     cmd.DW5.PhaseIndicator                              = paramsG12->ucPhaseIndicator;
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (m_decodeInUse)
-    {
-        if (cmd.DW1.PipeWorkingMode == MHW_VDBOX_HCP_PIPE_WORK_MODE_CABAC_REAL_TILE)
-        {
-            MOS_TraceEvent(EVENT_DECODE_FEATURE_RT_SCALABILITY, EVENT_TYPE_INFO, NULL, 0, NULL, 0);
-        }
-    }
-#endif
-
     MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, params->pBatchBuffer, &cmd, sizeof(cmd)));
 
     // for Gen11+, we need to add MFX wait for both KIN and VRT before and after AVP Pipemode select...
@@ -742,7 +732,7 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpPipeBufAddrCmd(
         resourceParams.dwOffset = 0;
         resourceParams.pdwCmd = (cmd.CdfTablesInitializationBufferAddress.DW0_1.Value);
         resourceParams.dwLocationInCmd = 27;
-        resourceParams.bIsWritable = true;
+        resourceParams.bIsWritable = false;
 
         MHW_MI_CHK_STATUS(AddResourceToCmd(
             m_osInterface,
@@ -1445,17 +1435,6 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpPipeBufAddrCmd(
             &resourceParams));
     }
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (m_decodeInUse)
-    {
-        if (cmd.DecodedOutputFrameBufferAddressAttributes.DW0.BaseAddressMemoryCompressionEnable && !bMMCReported)
-        {
-            MOS_TraceEvent(EVENT_DECODE_FEATURE_MMC, EVENT_TYPE_INFO, NULL, 0, NULL, 0);
-            bMMCReported = true;
-        }
-    }
-#endif
-
     MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
     return eStatus;
@@ -1696,9 +1675,20 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpDecodePicStateCmd(
         memset(refScaleFactor, 0, sizeof(refScaleFactor));
         memset(refFrameRes, 0, sizeof(refFrameRes));
 
-        for (auto i = 0; i < 7; i++)//i=0 corresponds to LAST_FRAME
+        for (auto i = 0; i < av1NumInterRefFrames; i++)  //i=0 corresponds to LAST_FRAME
         {
-            refPicIndex = refFrameList[picParams->m_refFrameIdx[i]].FrameIdx;
+            refPicIndex = 0xFF;
+            if (picParams->m_refFrameIdx[i] < av1TotalRefsPerFrame &&
+                refFrameList[picParams->m_refFrameIdx[i]].FrameIdx < CODECHAL_MAX_DPB_NUM_AV1)
+            {
+                refPicIndex = refFrameList[picParams->m_refFrameIdx[i]].FrameIdx;
+            }
+            else
+            {
+                refPicIndex = params->m_validRefPicIdx;
+            }
+            MHW_ASSERT(refPicIndex < CODECHAL_MAX_DPB_NUM_AV1);
+
             refFrameWidth[i]    = params->m_refList[refPicIndex]->m_frameWidth;
             refFrameHeight[i]   = params->m_refList[refPicIndex]->m_frameHeight;
 
@@ -1798,7 +1788,7 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpDecodeTileCodingCmd(
     uint8_t                 numVdbox = (uint8_t)gtSystemInfo->VDBoxInfo.NumberOfVDBoxEnabled;
 
     cmd.DW1.FrameTileId = params->m_tileId;
-    cmd.DW1.TgTileNum   = params->m_tileNum;
+    cmd.DW1.TgTileNum   = params->m_tgTileNum;
     cmd.DW1.TileGroupId = params->m_tileGroupId;
 
     cmd.DW2.TileColumnPositionInSbUnit  = params->m_tileColPositionInSb;
@@ -1840,7 +1830,7 @@ MOS_STATUS MhwVdboxAvpInterfaceG12::AddAvpDecodeTileCodingCmdLst(
     uint8_t                 numVdbox = (uint8_t)gtSystemInfo->VDBoxInfo.NumberOfVDBoxEnabled;
 
     cmd.DW1.FrameTileId = params->m_tileId;
-    cmd.DW1.TgTileNum   = params->m_tileNum;
+    cmd.DW1.TgTileNum   = params->m_tgTileNum;
     cmd.DW1.TileGroupId = params->m_tileGroupId;
 
     cmd.DW2.TileColumnPositionInSbUnit  = params->m_tileColPositionInSb;
