@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -26,6 +26,7 @@
 #include "codec_hw_next.h"
 #include "codechal_setting.h"
 #include "mos_os_cp_interface_specific.h"
+#include "mhw_vdbox_vvcp_itf.h"
 
 CodechalHwInterfaceNext::CodechalHwInterfaceNext(
     PMOS_INTERFACE     osInterface,
@@ -42,10 +43,12 @@ CodechalHwInterfaceNext::CodechalHwInterfaceNext(
     m_hcpItf   = mhwInterfacesNext->m_hcpItf;
     m_mfxItf   = mhwInterfacesNext->m_mfxItf;
     m_renderItf = mhwInterfacesNext->m_renderItf;
+    m_vvcpItf  = mhwInterfacesNext->m_vvcpItf;
 
     CODEC_HW_ASSERT(osInterface);
     m_osInterface = osInterface;
 
+    MOS_ZeroMemory(&m_platform, sizeof(PLATFORM));
     m_osInterface->pfnGetPlatform(m_osInterface, &m_platform);
 
     m_skuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
@@ -62,6 +65,10 @@ CodechalHwInterfaceNext::CodechalHwInterfaceNext(
     m_cpInterface     = mhwInterfacesNext->m_cpInterface;
     m_veboxInterface  = mhwInterfacesNext->m_veboxInterface;
     m_sfcInterface    = mhwInterfacesNext->m_sfcInterface;
+    //Prevent double free
+    mhwInterfacesNext->m_cpInterface    = nullptr;
+    mhwInterfacesNext->m_veboxInterface = nullptr;
+    mhwInterfacesNext->m_sfcInterface   = nullptr;
 
     m_disableScalability = disableScalability;
     m_userSettingPtr     = osInterface->pfnGetUserSettingInstance(osInterface);
@@ -78,11 +85,13 @@ CodechalHwInterfaceNext::~CodechalHwInterfaceNext()
         m_osInterface->pfnFreeResource(m_osInterface, &m_dummyStreamOut);
 
         m_osInterface->pfnFreeResource(m_osInterface, &m_conditionalBbEndDummy);
+        if (m_cpInterface)
+        {
+            m_osInterface->pfnDeleteMhwCpInterface(m_cpInterface);
+            m_cpInterface = nullptr;
+        }
     }
 
-    Delete_MhwCpInterface(m_cpInterface);
-    m_cpInterface = nullptr;
-
     if (m_veboxInterface)
     {
         m_veboxInterface->DestroyHeap();
@@ -338,7 +347,7 @@ MOS_STATUS CodechalHwInterfaceNext::GetVdencPictureSecondLevelCommandsSize(
 {
     CODEC_HW_FUNCTION_ENTER;
 
-    uint32_t commands = 0;
+    uint32_t commandSz = 0;
 
     MHW_MI_CHK_NULL(m_hcpItf);
 
@@ -346,12 +355,12 @@ MOS_STATUS CodechalHwInterfaceNext::GetVdencPictureSecondLevelCommandsSize(
 
     if (standard == CODECHAL_VP9)
     {
-        commands += m_hcpItf->GetHcpVp9PicStateCommandSize();
-        commands += m_hcpItf->GetHcpVp9SegmentStateCommandSize() * 8;
-        commands += 132;
-        commands += 248;
-        commands += m_sizeOfCmdBatchBufferEnd;
-        commands += 24; // padding for alignment on 64 
+        commandSz += m_hcpItf->GetHcpVp9PicStateCommandSize();
+        commandSz += m_hcpItf->GetHcpVp9SegmentStateCommandSize() * 8;
+        commandSz += m_vdencItf->GetCmd1CommandSize();
+        commandSz += m_vdencItf->GetCmd2CommandSize();
+        commandSz += m_sizeOfCmdBatchBufferEnd;
+        commandSz += (MOS_ALIGN_CEIL(commandSz, 64) - commandSz); // padding for alignment on 64 
     }
     else
     {
@@ -359,7 +368,7 @@ MOS_STATUS CodechalHwInterfaceNext::GetVdencPictureSecondLevelCommandsSize(
         return MOS_STATUS_UNKNOWN;
     }
 
-    *commandsSize = commands;
+    *commandsSize = commandSz;
 
     return MOS_STATUS_SUCCESS;
 }
@@ -388,6 +397,10 @@ MOS_STATUS CodechalHwInterfaceNext::SetCacheabilitySettings(
     {
         CODEC_HW_CHK_STATUS_RETURN(m_vdencItf->SetCacheabilitySettings(cacheabilitySettings));
     }
+    if (m_vvcpItf != nullptr)
+    {
+        CODEC_HW_CHK_STATUS_RETURN(m_vvcpItf->SetCacheabilitySettings(cacheabilitySettings));
+    }
 
     return eStatus;
 }
@@ -628,6 +641,90 @@ MOS_STATUS CodechalHwInterfaceNext::GetHcpPrimitiveCommandSize(
     return eStatus;
 }
 
+MOS_STATUS CodechalHwInterfaceNext::GetVvcpStateCommandSize(
+    uint32_t                        mode,
+    uint32_t                       *commandsSize,
+    uint32_t                       *patchListSize,
+    PMHW_VDBOX_STATE_CMDSIZE_PARAMS params)
+{
+    CODEC_HW_FUNCTION_ENTER;
+
+    //calculate VVCP related commands size
+    uint32_t vvcpCommandsSize  = 0;
+    uint32_t vvcpPatchListSize = 0;
+    uint32_t cpCmdsize         = 0;
+    uint32_t cpPatchListSize   = 0;
+
+    if (m_vvcpItf)
+    {
+        CODEC_HW_CHK_STATUS_RETURN(m_vvcpItf->GetVvcpStateCmdSize(
+             (uint32_t *)&vvcpCommandsSize,
+             (uint32_t *)&vvcpPatchListSize,
+             params));
+    }
+
+    if (m_cpInterface)
+    {
+        m_cpInterface->GetCpStateLevelCmdSize(cpCmdsize, cpPatchListSize);
+    }
+
+    //Calc final command size
+    *commandsSize  = vvcpCommandsSize + cpCmdsize;
+    *patchListSize = vvcpPatchListSize + cpPatchListSize;
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS CodechalHwInterfaceNext::GetVvcpSliceLvlCmdSize(uint32_t *sliceLvlCmdSize)
+{
+    CODEC_HW_FUNCTION_ENTER;
+    if (m_vvcpItf)
+    {
+        CODEC_HW_CHK_STATUS_RETURN(m_vvcpItf->GetVvcpSliceLvlCmdSize(sliceLvlCmdSize));
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS CodechalHwInterfaceNext::GetVvcpPrimitiveCommandSize(
+    uint32_t  mode,
+    uint32_t *sliceCommandsSize,
+    uint32_t *slicePatchListSize,
+    uint32_t *tileCommandsSize,
+    uint32_t *tilePatchListSize)
+{
+    CODEC_HW_FUNCTION_ENTER;
+
+    //calculate VVCP related commands size
+    uint32_t vvcpSliceCommandsSize  = 0;
+    uint32_t vvcpSlicePatchListSize = 0;
+    uint32_t vvcpTileCommandsSize   = 0;
+    uint32_t vvcpTilePatchListSize  = 0;
+    uint32_t cpCmdsize              = 0;
+    uint32_t cpPatchListSize        = 0;
+
+    if (m_vvcpItf)
+    {
+        CODEC_HW_CHK_STATUS_RETURN(m_vvcpItf->GetVvcpPrimitiveCmdSize(
+            (uint32_t *)&vvcpSliceCommandsSize,
+            (uint32_t *)&vvcpSlicePatchListSize,
+            (uint32_t *)&vvcpTileCommandsSize,
+            (uint32_t *)&vvcpTilePatchListSize));
+    }
+
+    if (m_cpInterface)
+    {
+        m_cpInterface->GetCpSliceLevelCmdSize(cpCmdsize, cpPatchListSize);
+    }
+
+    //Calc final command size
+    *sliceCommandsSize  = vvcpSliceCommandsSize + cpCmdsize;
+    *slicePatchListSize = vvcpSlicePatchListSize + cpPatchListSize;
+    *tileCommandsSize   = vvcpTileCommandsSize;
+    *tilePatchListSize  = vvcpTilePatchListSize;
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS CodechalHwInterfaceNext::AddHucDummyStreamOut(
     PMOS_COMMAND_BUFFER cmdBuffer)
 {
@@ -993,7 +1090,18 @@ MOS_STATUS CodechalHwInterfaceNext::SetRowstoreCachingOffsets(
     }
     if (m_avpItf)
     {
-        CODEC_HW_CHK_STATUS_RETURN(m_avpItf->GetRowstoreCachingAddrs());
+        mhw::vdbox::avp::AvpVdboxRowStorePar rowstoreParamsAVP = {};
+        rowstoreParamsAVP.picWidth       = rowstoreParams->dwPicWidth;
+        rowstoreParamsAVP.mbaff          = rowstoreParams->bMbaff;
+        rowstoreParamsAVP.mode           = rowstoreParams->Mode;
+        rowstoreParamsAVP.bitDepthMinus8 = rowstoreParams->ucBitDepthMinus8;
+        rowstoreParamsAVP.chromaFormat   = rowstoreParams->ucChromaFormat;
+        CODEC_HW_CHK_STATUS_RETURN(m_avpItf->GetRowstoreCachingAddrs(rowstoreParamsAVP));
+    }
+
+    if (m_vvcpItf != nullptr)
+    {
+        CODEC_HW_CHK_STATUS_RETURN(m_vvcpItf->GetRowstoreCachingAddrs(rowstoreParams));
     }
 
     return eStatus;
