@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020 -2023, Intel Corporation
+* Copyright (c) 2020-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -167,6 +167,9 @@ struct _MHW_PAR_T(VDENC_PIPE_MODE_SELECT)
     uint8_t wirelessSessionId        = 0;
     uint8_t tailPointerReadFrequency = 0;
     uint8_t streamingBufferConfig    = 0;
+    bool    bt2020RGB2YUV            = 0;
+    uint8_t rgbInputStudioRange      = 0;
+    uint8_t convertedYUVStudioRange  = 0;
     uint8_t VdencPipeModeSelectPar0  = 0;
     uint8_t VdencPipeModeSelectPar1  = 0;
     uint8_t VdencPipeModeSelectPar2  = 0;
@@ -176,6 +179,12 @@ struct _MHW_PAR_T(VDENC_PIPE_MODE_SELECT)
     uint8_t VdencPipeModeSelectPar6  = 0;
     uint8_t VdencPipeModeSelectPar7  = 0;
     uint8_t VdencPipeModeSelectPar8  = 0;
+    bool    fastPassEn               = false;
+    uint8_t fastPassScale            = 0;
+    uint8_t DownScaleType            = 0;
+    uint8_t VdencPipeModeSelectPar12 = 0;
+    uint8_t VdencPipeModeSelectPar13 = 0;
+    bool    chromaPrefetchDisable    = false;
 };
 
 struct _MHW_PAR_T(VDENC_SRC_SURFACE_STATE)
@@ -267,6 +276,7 @@ struct _MHW_PAR_T(VDENC_PIPE_BUF_ADDR_STATE)
     PMOS_RESOURCE     colocatedMvWriteBuffer            = nullptr;
     PMOS_RESOURCE     vdencPipeBufAddrStatePar0         = nullptr;
     PMOS_RESOURCE     vdencPipeBufAddrStatePar1         = nullptr;
+    PMOS_RESOURCE     vdencPipeBufAddrStatePar2         = nullptr;
 };
 
 struct _MHW_PAR_T(VDENC_WEIGHTSOFFSETS_STATE)
@@ -320,6 +330,7 @@ struct _MHW_PAR_T(VDENC_HEVC_VP9_TILE_SLICE_STATE)
     uint32_t VdencHEVCVP9TileSlicePar22    = 0;
     uint32_t VdencHEVCVP9TileSlicePar23    = 0;
     uint32_t VdencHEVCVP9TileSlicePar24    = 0;
+    uint32_t tileRowstoreOffset            = 0;
 };
 
 struct _MHW_PAR_T(VDENC_WALKER_STATE)
@@ -333,17 +344,22 @@ struct _MHW_PAR_T(VDENC_WALKER_STATE)
 
 struct _MHW_PAR_T(VD_PIPELINE_FLUSH)
 {
-    bool waitDoneHEVC           = false;
-    bool waitDoneVDENC          = false;
-    bool waitDoneMFL            = false;
-    bool waitDoneMFX            = false;
-    bool waitDoneVDCmdMsgParser = false;
-    bool flushHEVC              = false;
-    bool flushVDENC             = false;
-    bool flushMFL               = false;
-    bool flushMFX               = false;
-    bool waitDoneAV1            = false;
-    bool flushAV1               = false;
+    bool waitDoneHEVC             = false;
+    bool waitDoneVDENC            = false;
+    bool waitDoneMFL              = false;
+    bool waitDoneMFX              = false;
+    bool waitDoneVDCmdMsgParser   = false;
+    bool flushHEVC                = false;
+    bool flushVDENC               = false;
+    bool flushMFL                 = false;
+    bool flushMFX                 = false;
+    bool waitDoneAV1              = false;
+    bool flushAV1                 = false;
+    bool waitDoneVDAQM            = false;
+    bool flushVDAQM               = false;
+    bool vvcpPipelineDone         = false;
+    bool vvcpPipelineCommandFlush = false;
+
     __MHW_VDBOX_VDENC_WRAPPER_EXT(VD_PIPELINE_FLUSH_CMDPAR_EXT);
 };
 
@@ -519,7 +535,6 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint32_t height                           = 0;
     bool     constrainedIntraPred             = false;
     uint8_t  pictureType                      = 0;
-    bool     av1IdentityTransform             = false;
     bool     temporalMvp                      = false;
     bool     collocatedFromL0                 = false;
     uint8_t  longTermReferenceFlagsL0         = 0;
@@ -552,7 +567,7 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint8_t  intraRefreshMbSizeMinus1         = 1;
     uint8_t  intraRefreshMode                 = 0;
     bool     intraRefresh                     = false;
-    uint8_t  qpAdjustmentForRollingI          = 0;
+    int8_t   qpAdjustmentForRollingI          = 0;
     uint8_t  qpForSegs[8]                     = {};
     bool     vp9DynamicSlice                  = false;
     uint8_t  qpPrimeYDc                       = 0;
@@ -560,26 +575,7 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint32_t intraRefreshBoundary[3]          = {};
     uint8_t  av1RefId[2][4]                   = {{1, 1, 1, 1}, {1, 1, 1, 1}};
     uint8_t  subPelMode                       = 3;
-    bool     vdencCmd2Par113                  = false;
-    uint8_t  vdencCmd2Par114                  = 0;
-    uint8_t  vdencCmd2Par115                  = 0;
-    uint8_t  vdencCmd2Par116                  = 0;
-    uint8_t  vdencCmd2Par117                  = 0;
-    uint8_t  vdencCmd2Par118                  = 0;
-    uint8_t  vdencCmd2Par119                  = 0;
-    uint8_t  vdencCmd2Par120                  = 0;
-    uint8_t  vdencCmd2Par121                  = 0;
-    uint8_t  vdencCmd2Par122                  = 0;
-    uint8_t  vdencCmd2Par123                  = 0;
-    uint8_t  vdencCmd2Par124                  = 0;
-    uint8_t  vdencCmd2Par125                  = 0;
-    uint8_t  vdencCmd2Par126                  = 0;
-    uint8_t  vdencCmd2Par127                  = 0;
-    uint8_t  vdencCmd2Par128                  = 0;
-    uint8_t  vdencCmd2Par129                  = 0;
-    uint8_t  vdencCmd2Par130                  = 0;
-    uint8_t  vdencCmd2Par131                  = 0;
-    uint8_t  vdencCmd2Par132                  = 0;
+    uint8_t  av1EnableIntraEdgeFilter         = 0;
 
     __MHW_VDBOX_VDENC_WRAPPER(
         std::vector<std::function<MOS_STATUS(uint32_t *)>> extSettings);
